@@ -4,6 +4,9 @@
 #include "cbor_free_common.h"
 #include "cbor_free_boolean.h"
 
+#define CBF_FLAG_PRESERVE_REFERENCES 1
+#define CBF_FLAG_NAIVE_UTF8 2
+
 //----------------------------------------------------------------------
 // Definitions
 
@@ -18,6 +21,8 @@ typedef struct {
     void **reflist;
     UV reflistlen;
 
+    bool naive_utf8;
+
     union {
         uint8_t bytes[30];  // used for num -> key conversions
         float as_float;
@@ -37,6 +42,6 @@ struct numbuf {
 
 //----------------------------------------------------------------------
 
-SV *cbf_decode( pTHX_ SV *cbor, HV *tag_handler, bool preserve_refs );
+SV *cbf_decode( pTHX_ SV *cbor, HV *tag_handler, UV flags );
 
 #endif
